@@ -1,5 +1,6 @@
 import dataclasses
 import sys
+import typing
 import unittest
 from typing import Dict, List, Optional
 from irisml.core import Context, TaskBase, TaskDescription
@@ -75,3 +76,43 @@ class TestTask(unittest.TestCase):
             task = Task(task_description)
             task.load_module()
             task.execute(context)
+
+    def test_literal_env(self):
+        # The Env variable should work for typing.Literal.
+        task_description = TaskDescription.from_dict({'task': 'custom_task', 'inputs': {'input0': '$env.ENV_INPUT'}, 'config': {'config0': '$env.ENV_CONFIG', 'config1': '$env.ENV_CONFIG2'}})
+
+        class CustomTask:
+            class Task(TaskBase):
+                @dataclasses.dataclass
+                class Inputs:
+                    input0: typing.Literal['r2d2', 'c3po']
+
+                @dataclasses.dataclass
+                class Config:
+                    config0: typing.Literal['365', '42']
+                    config1: typing.Literal[365, 42]
+
+                def execute(self, inputs):
+                    if inputs.input0 not in ['r2d2', 'c3po']:
+                        raise RuntimeError
+                    if self.config.config0 not in ['365', '42']:
+                        raise RuntimeError
+                    if self.config.config1 not in [365, 42]:
+                        raise RuntimeError
+                    return self.Outputs()
+
+        context = Context({'ENV_INPUT': 'r2d2', 'ENV_CONFIG': '42', 'ENV_CONFIG2': '42'})
+        with unittest.mock.patch.dict(sys.modules):
+            sys.modules['irisml.tasks.custom_task'] = CustomTask
+            task = Task(task_description)
+            task.load_module()
+            task.execute(context)
+
+        # Those values are not in the Literal types.
+        context = Context({'ENV_INPUT': 'unknown', 'ENV_CONFIG': '111', 'ENV_CONFIG2': '111'})
+        with unittest.mock.patch.dict(sys.modules):
+            sys.modules['irisml.tasks.custom_task'] = CustomTask
+            with self.assertRaises(ValueError):
+                task = Task(task_description)
+                task.load_module()
+                task.execute(context)
